@@ -144,7 +144,6 @@ class Routing(BaseRouting):
         """
         #pylint:disable=inconsistent-return-statements
         path = request.path
-        method = request.method
         is_static = self._add_static_routes(path)
         method = request.method
         if not is_static:
@@ -158,6 +157,7 @@ class Routing(BaseRouting):
                     white_routes = self._prefix_api_name(self.config.whitelist_routes)
                     not_whitelist = self._allow_public_routes(white_routes)
                     if not_whitelist:
+                        self.entity.clean_up()
                         self._handle_token()
 
     def _handle_token(self):
@@ -166,24 +166,32 @@ class Routing(BaseRouting):
         Checks to see that the route is white listed.
         :return None:
         """
-        self.entity.clean_up()
+        entity = None
         try:
             if request.args.get("auth"):
                 token = request.args.get("auth")
-            elif request.headers.get("X-Auth-Token") and self.google:
+            elif request.headers.get("X-Auth-Token") is not None and self.google:
                 bearer = request.headers.get("X-Auth-Token")
                 token = bearer.split("Bearer ")[1]
                 try:
-                    # Currently token refreshing is not supported, so pass the current token through
-                    auth_results = self.google.authorize(token)
-                    email = auth_results["email"]
+                    if self.google.test_metadata:
+                        email, entity = self.google._update_test_metadata(token)
+                    else:
+                        # Currently token refreshing is not supported, so pass the current token through
+                        auth_results = self.google.authorize(token)
+                        email = auth_results["email"]
                     self.entity.oauth_entity_key = self.config.oauth_entity
-                    entity = self.entity.get_entity_from_token_or_tablename(
-                        tablename=self.google.tablename,
-                        email_value=email,
-                    )
-                    setattr(g, self.entity.get_entity_from_ext().__tablename__, entity)
+                    if not entity:
+                        entity = self.entity.get_entity_from_token_or_tablename(
+                            tablename=self.google.tablename,
+                            email_value=email,
+                        )
+                        setattr(g, self.entity.get_entity_from_ext().__tablename__, entity)
+                    else:
+                        setattr(g, entity.__tablename__, entity)
                     setattr(g, "access_token", token)
+                    # Clean up google test util
+                    self.google.tear_down()
                     return None
                 except InvalidTokenError:
                     return abort(401)
